@@ -191,6 +191,7 @@ def symlink_force(src: str, dst: str, hard: bool = False) -> None:
     Create a symbolic pointing to src named dst, atomically replacing any existing symbolic or
     hard link at dst.
     """
+    assert not dst.endswith("/")
     tn = dst + ".tmp." + str(uuid.uuid1())
     if hard:
         os.link(src, tn)
@@ -215,7 +216,12 @@ def write_values_json(
     from . import values_to_json
 
     write_atomic(
-        json.dumps(values_to_json(values_env, namespace=namespace), indent=2),  # pyre-ignore
+        json.dumps(
+            # pyre-ignore
+            values_to_json(values_env, namespace=namespace),
+            indent=2,
+            sort_keys=True,
+        ),
         filename,
     )
 
