@@ -487,7 +487,6 @@ def _scatter(
     last_scatter_indices = None
     scatter_tags = _scatter_tags(array, max_tag)
     for i, array_i in enumerate(array):
-
         # scatter bookkeeping: format the index as a left-zero-padded string so that it'll sort
         # lexicographically in the desired order; bind the scatter variable name to the array value
         scatter_stack_i = scatter_stack
@@ -559,9 +558,9 @@ def _scatter_tags(array: List[Optional[Value.Base]], max_tag: int) -> List[str]:
     # human-readability, and can be embedded in the run id/directory safely. This is to help the
     # operator navigate the run logs & directory tree, looking for specific items.
 
-    # stringify each item and split each string into a list of alphanumeric components
+    # stringify each item and split each string into a list of identifier-like components
     any = False
-    delimiters = regex.compile("[^0-9a-zA-Z]+")
+    delimiters = regex.compile("[^0-9a-zA-Z_]+")
     items = []
     for i, array_i in enumerate(array):
         if (
