@@ -12,6 +12,8 @@ class TestEval(unittest.TestCase):
         self.assertEqual(str(WDL.parse_expr('{"A": "Map"}')), '{"A": "Map"}')
         self.assertEqual(str(WDL.parse_expr('("A", "Pair")')), '("A", "Pair")')
         self.assertEqual(str(WDL.parse_expr('object {"A": "struct"}', "1.0")), '{"A": "struct"}')
+        self.assertEqual(str(WDL.parse_expr('''object {"A\\\\": 'struct'}''', "1.0")), '''{"A\\": 'struct'}''')
+        self.assertEqual(str(WDL.parse_expr('''object {'A\\\\': 'struct'}''', "1.0")), '''{"A\\": 'struct'}''')
 
         # logic
         self.assertEqual(str(WDL.parse_expr("true && false")), "true && false")
@@ -221,6 +223,13 @@ class TestEval(unittest.TestCase):
         for i in range(len(junk)):
             junk[i] = ('"' + junk[i] + '"', json.dumps(junk[i]))
         self._test_tuples(*junk)
+        # string literals ending in backslash
+        self._test_tuples(
+            ('''"\\\\"''', '''"\\\\"'''),
+            ("""'\\\\'""", '''"\\\\"'''),
+            ('''"\\"\\\\"''', '''"\\"\\\\"'''),
+            ("""'\\'\\\\'""", '''"'\\\\"''')
+        )
 
     def test_compound_equality(self):
         self._test_tuples(
@@ -397,6 +406,16 @@ class TestEval(unittest.TestCase):
             ("true || 1/0 == 1", "true"),
         )
 
+    def test_multi_line_strings(self):
+        # NOTE: most of the multi-line string tests are in tests/multi_line_strings.wdl which runs
+        # in the integration suite. Generally easier to write there without having to double-escape
+        # (python+WDL). These are here mainly to provide code coverage.
+        env = cons_env(("color", WDL.Value.String("brown")))
+        self._test_tuples(
+            ("<<< \n  \\\n  >>>", '""', "development"),
+            ("<<<\n    quick ~{color}\n  fox\n  >>>", json.dumps("  quick brown\nfox"), env, "development")
+        )
+
 def cons_env(*bindings):
     b = WDL.Env.Bindings()
     for (x,y) in bindings:
