@@ -224,7 +224,6 @@ class gatk4_somatic_snvs_indels(unittest.TestCase):
         "UnusedCall": 1,
         "StringCoercion": 4,
         "MissingVersion": 6,
-        "Deprecated": 1,
     },
     check_quant=False,
 )
@@ -399,21 +398,20 @@ class dxWDL(unittest.TestCase):
         "_suppressions": 8,
         "UnusedImport": 4,
         "NameCollision": 27,
-        "StringCoercion": 8,
+        "StringCoercion": 7,
         "FileCoercion": 3,
         "NonemptyCoercion": 1,
         "UnnecessaryQuantifier": 5,
-        "UnusedDeclaration": 2,
+        "UnusedDeclaration": 4,
         "IncompleteCall": 2,
         "SelectArray": 1,
         "MissingVersion": 7,
         "UnboundDeclaration": 1,
         "UnverifiedStruct": 3,
-        "Deprecated": 10,
-        "OptionalCoercion": 1,
+        "Deprecated": 2,
         "UnexpectedRuntimeValue": 1,
     },
-    blocklist=["check_quant", "incomplete_call"],
+    blocklist=["check_quant", "incomplete_call", "issue596"],
 )
 class Contrived(unittest.TestCase):
     pass
@@ -427,17 +425,17 @@ class Contrived(unittest.TestCase):
         "NameCollision": 43,
         "StringCoercion": 13,
         "FileCoercion": 5,
-        "OptionalCoercion": 4,
+        "OptionalCoercion": 10,
         "NonemptyCoercion": 2,
         "UnnecessaryQuantifier": 9,
-        "UnusedDeclaration": 9,
+        "UnusedDeclaration": 11,
         "IncompleteCall": 3,
         "ArrayCoercion": 2,
         "SelectArray": 4,
         "MissingVersion": 11,
         "UnboundDeclaration": 1,
         "UnverifiedStruct": 3,
-        "Deprecated": 11,
+        "Deprecated": 3,
         "UnexpectedRuntimeValue": 1,
     },
     check_quant=False,
@@ -453,16 +451,17 @@ class Contrived2(unittest.TestCase):
         # these use the pattern 'input { Type? x = default }' and need check_quant=False
         "mergecounts",
         "somaticseq",
+        "bamstats",
+        "biopet",
+        "sampleconfig",
+        "seqstat",
     ],
     expected_lint={
-        "OptionalCoercion": 9,
-        "UnusedDeclaration": 18,
+        "OptionalCoercion": 2,
+        "UnusedDeclaration": 15,
         "NonemptyCoercion": 1,
-        "NameCollision": 1,
         "SelectArray": 1,
-        "UnverifiedStruct": 1,
         "UnnecessaryQuantifier": 8,
-        "Deprecated": 7,
     },
 )
 class BioWDLTasks(unittest.TestCase):
@@ -478,7 +477,6 @@ class BioWDLTasks(unittest.TestCase):
         "NameCollision": 1,
         "UnverifiedStruct": 1,
         "UnnecessaryQuantifier": 13,
-        "Deprecated": 7,
     },
     check_quant=False,
 )
@@ -495,7 +493,6 @@ class BioWDLAligning(unittest.TestCase):
         "NameCollision": 1,
         "UnverifiedStruct": 1,
         "UnnecessaryQuantifier": 9,
-        "Deprecated": 7,
     },
     check_quant=False,
 )
@@ -512,7 +509,6 @@ class BioWDLExpressionQuantification(unittest.TestCase):
         "NonemptyCoercion": 37,
         "SelectArray": 5,
         "UnnecessaryQuantifier": 3,
-        "Deprecated": 8,
     },
     check_quant=False,
 )
