@@ -4,7 +4,6 @@ import tempfile
 import random
 import os
 import shutil
-import json
 import time
 import docker
 import platform
@@ -926,6 +925,34 @@ class MiscRegressionTests(RunnerTestCase):
         self.assertEqual(outp["fivethree"], [5, 3])
         self.assertEqual(outp["is_true"], True)
 
+    def test_issue596(self):
+        self._run("""
+        task reference_prepare {
+            input {
+                # You need to define either this...
+                File? reference_fa_file
+
+                # Or both of these.
+                File?   reference_zipped_directory
+                String? reference_fa_filename_in_zipped_directory
+            }
+
+            # get the basename of the reference
+            String? basename_reference = basename(reference_zipped_directory)
+
+            command <<<
+                set -eux -o pipefail
+
+                if [[ ! "~{reference_zipped_directory}" = "" ]]
+                then
+                    cp ~{reference_zipped_directory} .
+                    unzip ~{basename_reference}
+                fi
+
+                # do other things here
+            >>>
+        }""", {}, expected_exception=WDL.Error.StaticTypeMismatch)
+
     def test_issue614(self):
         wdl = r"""
         version 1.0
@@ -962,6 +989,45 @@ class MiscRegressionTests(RunnerTestCase):
         outp = self._run(wdl, {"create_file": True})
         self.assertTrue(os.path.exists(outp["out"][0]))
 
+    @unittest.expectedFailure # issue #623
+    def test_output_symlink_to_input(self):
+        wdl = r"""
+        version 1.0
+        task create_file {
+            input {}
+            command <<<
+                echo hello > hello.txt
+            >>>
+            output {
+                File file = "hello.txt"
+            }
+        }
+        task use_file {
+            input {
+                File file_in
+            }
+            command <<<
+                ln -s ~{file_in} hello_link.txt
+                >&2 ls -lR
+            >>>
+            output {
+                File file = "hello_link.txt"
+            }
+        }
+        workflow maybe_file {
+            input {}
+            call create_file
+            call use_file {
+                input:
+                file_in = create_file.file
+            }
+            output {
+                Array[File] files = [create_file.file, use_file.file]
+            }
+        }
+        """
+        outp = self._run(wdl, {})
+
 class TestInlineDockerfile(RunnerTestCase):
     @log_capture()
     def test1(self, capture):
